@@ -1,6 +1,8 @@
 from enum import Enum
 
 # TODO: rename HardwareType to HardwareName and inferenceHardware to HardwareType
+from typing import Optional
+
 from deci_common.data_types.enum.models_enums import BatchSize, BatchSizeEdge
 from deci_common.helpers import get_enum_values
 
@@ -34,6 +36,7 @@ class HardwareType(str, Enum):
     Icelake = "Icelake"
     NUC_TIGER_LAKE = "Intel NUC Tiger Lake"
     SKYLAKE_SP = "Skylake-SP"
+    CASCADE_LAKE_GCP = "Cascade Lake GCP"
 
     HAILO8 = "Hailo-8"
     AMBARELLA = "Ambarella"
@@ -103,6 +106,7 @@ class HardwareMachineModel(str, Enum):
     EPYC_7003 = "m6a.4xlarge"
     SKYLAKE_SP = "m5.2xlarge"
     A100_40G = "a2-highgpu-1g"
+    CASCADE_LAKE_GCP = "n2-standard-4"
 
     NANO = HardwareType.NANO.value
     XAVIER = HardwareType.XAVIER.value
@@ -166,6 +170,7 @@ class MapHardwareTypeToFamily(str, Enum):
     Icelake = InferenceHardware.CPU.value
     NUC_TIGER_LAKE = InferenceHardware.CPU.value
     SKYLAKE_SP = InferenceHardware.CPU.value
+    CASCADE_LAKE_GCP = InferenceHardware.CPU.value
 
 
 class InferyVersion(str, Enum):
@@ -204,6 +209,7 @@ class MapHardwareTypeToInferyVersion(str, Enum):
     Icelake = InferyVersion.CPU.value
     NUC_TIGER_LAKE = InferyVersion.CPU.value
     SKYLAKE_SP = InferyVersion.CPU.value
+    CASCADE_LAKE_GCP = InferyVersion.CPU.value
 
 
 class HardwareEnvironment(str, Enum):
@@ -244,6 +250,7 @@ class HardwareTaint(str, Enum):
     Icelake = "intel.com/icelake"
     NUC_TIGER_LAKE = "intel.com/nuc-tiger-lake"
     SKYLAKE_SP = "intel.com/skylake-sp"
+    CASCADE_LAKE_GCP = "intel.com/xeon"
 
 
 class HardwareLabel(str, Enum):
@@ -272,6 +279,7 @@ class HardwareLabel(str, Enum):
     Icelake = "intel-icelake"
     NUC_TIGER_LAKE = "intel-nuc-tiger-lake"
     SKYLAKE_SP = "intel-skylake-sp"
+    CASCADE_LAKE_GCP = "intel-xeon"
 
 
 class MapHardwareTypeToVendor(str, Enum):
@@ -297,6 +305,7 @@ class MapHardwareTypeToVendor(str, Enum):
     Icelake = HardwareVendor.INTEL.value
     NUC_TIGER_LAKE = HardwareVendor.INTEL.value
     SKYLAKE_SP = HardwareVendor.INTEL.value
+    CASCADE_LAKE_GCP = HardwareVendor.INTEL.value
 
 
 class MapHardwareTypeToEnvironment(str, Enum):
@@ -305,8 +314,6 @@ class MapHardwareTypeToEnvironment(str, Enum):
     K80 = HardwareEnvironment.AWS.value
     T4 = HardwareEnvironment.AWS.value
     A10G = HardwareEnvironment.AWS.value
-    A100_40G = HardwareEnvironment.GCP.value
-    A100_80G = HardwareEnvironment.GCP.value
     CPU = HardwareEnvironment.AWS.value
     EPYC = HardwareEnvironment.AWS.value
     EPYC_7002 = HardwareEnvironment.AWS.value
@@ -317,6 +324,11 @@ class MapHardwareTypeToEnvironment(str, Enum):
     Icelake = HardwareEnvironment.AWS.value
     SKYLAKE_SP = HardwareEnvironment.AWS.value
 
+    # GCP
+    A100_40G = HardwareEnvironment.GCP.value
+    A100_80G = HardwareEnvironment.GCP.value
+    CASCADE_LAKE_GCP = HardwareEnvironment.GCP.value
+
     # PREMISE
     NANO = HardwareEnvironment.PREMISE.value
     XAVIER = HardwareEnvironment.PREMISE.value
@@ -350,6 +362,7 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):
     Icelake = get_enum_values(BatchSize)
     NUC_TIGER_LAKE = get_enum_values(BatchSize)
     SKYLAKE_SP = get_enum_values(BatchSize)
+    CASCADE_LAKE_GCP = get_enum_values(BatchSize)
 
 
 class HardwareImageRepository(str, Enum):
@@ -418,6 +431,7 @@ class MapHardwareTypeToGroup(str, Enum):
     Broadwell = HardwareGroup.CPU.value
     Icelake = HardwareGroup.CPU.value
     SKYLAKE_SP = HardwareGroup.CPU.value
+    CASCADE_LAKE_GCP = HardwareGroup.CPU.value
 
     APPLE_IPHONE_A11 = HardwareGroup.CONSUMER_EDGE.value
     APPLE_IPHONE_A12 = HardwareGroup.CONSUMER_EDGE.value
@@ -433,7 +447,7 @@ class MapHardwareTypeToGroup(str, Enum):
     EXYNOS_2200 = HardwareGroup.CONSUMER_EDGE.value
 
 
-def type_with_model(model: HardwareMachineModel, override_label: str = None) -> str:
+def type_with_model(model: HardwareMachineModel, override_label: Optional[str] = None) -> str:
     return f"{override_label or HardwareType[model.name].value} ({model})"
 
 
@@ -458,6 +472,7 @@ class HardwareTypeLabel(str, Enum):
     T4 = type_with_model(HardwareMachineModel.T4)
     A10G = type_with_model(HardwareMachineModel.A10G)
     A100_40G = type_with_model(HardwareMachineModel.A100_40G, "A100 40GB")
+    CASCADE_LAKE_GCP = type_with_model(HardwareMachineModel.CASCADE_LAKE_GCP, "Cascade Lake")
 
     A100_80G = HardwareType.A100_80G.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
